==> infima_client-0.59.0-py3-none-any.whl: infima_client/models/cohort_summary.py <==
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="CohortSummary")


@attr.s(auto_attribs=True)
class CohortSummary:
    """  """

    average_security_factor: Union[Unset, float] = UNSET
    average_wac: Union[Unset, float] = UNSET
    coupon: Union[Unset, float] = UNSET
    current_upb: Union[Unset, float] = UNSET
    name: Union[Unset, str] = UNSET
    num_pools: Union[Unset, int] = UNSET
    ticker: Union[Unset, str] = UNSET
    type: Union[Unset, str] = UNSET
    upb_at_issuance: Union[Unset, float] = UNSET
    vintage: Union[Unset, int] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        average_security_factor = self.average_security_factor
        average_wac = self.average_wac
        coupon = self.coupon
        current_upb = self.current_upb
        name = self.name
        num_pools = self.num_pools
        ticker = self.ticker
        type = self.type
        upb_at_issuance = self.upb_at_issuance
        vintage = self.vintage

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if average_security_factor is not UNSET:
            field_dict["averageSecurityFactor"] = average_security_factor
        if average_wac is not UNSET:
            field_dict["averageWac"] = average_wac
        if coupon is not UNSET:
            field_dict["coupon"] = coupon
        if current_upb is not UNSET:
            field_dict["currentUpb"] = current_upb
        if name is not UNSET:
            field_dict["name"] = name
        if num_pools is not UNSET:
            field_dict["numPools"] = num_pools
        if ticker is not UNSET:
            field_dict["ticker"] = ticker
        if type is not UNSET:
            field_dict["type"] = type
        if upb_at_issuance is not UNSET:
            field_dict["upbAtIssuance"] = upb_at_issuance
        if vintage is not UNSET:
            field_dict["vintage"] = vintage

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        average_security_factor = d.pop("averageSecurityFactor", UNSET)

        average_wac = d.pop("averageWac", UNSET)

        coupon = d.pop("coupon", UNSET)

        current_upb = d.pop("currentUpb", UNSET)

        name = d.pop("name", UNSET)

        num_pools = d.pop("numPools", UNSET)

        ticker = d.pop("ticker", UNSET)

        type = d.pop("type", UNSET)

        upb_at_issuance = d.pop("upbAtIssuance", UNSET)

        vintage = d.pop("vintage", UNSET)

        cohort_summary = cls(
            average_security_factor=average_security_factor,
            average_wac=average_wac,
            coupon=coupon,
            current_upb=current_upb,
            name=name,
            num_pools=num_pools,
            ticker=ticker,
            type=type,
            upb_at_issuance=upb_at_issuance,
            vintage=vintage,
        )

        cohort_summary.additional_properties = d
        return cohort_summary

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> infima_client-0.186.0-py3-none-any.whl: infima_client/models/cohort_summary.py <==
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="CohortSummary")


@attr.s(auto_attribs=True)
class CohortSummary:
    """  """

    average_security_factor: Union[Unset, float] = UNSET
    average_wac: Union[Unset, float] = UNSET
    coupon: Union[Unset, float] = UNSET
    iss_upb: Union[Unset, float] = UNSET
    name: Union[Unset, str] = UNSET
    num_loans: Union[Unset, int] = UNSET
    num_pools: Union[Unset, int] = UNSET
    ticker: Union[Unset, str] = UNSET
    type: Union[Unset, str] = UNSET
    upb: Union[Unset, float] = UNSET
    vintage: Union[Unset, int] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        average_security_factor = self.average_security_factor
        average_wac = self.average_wac
        coupon = self.coupon
        iss_upb = self.iss_upb
        name = self.name
        num_loans = self.num_loans
        num_pools = self.num_pools
        ticker = self.ticker
        type = self.type
        upb = self.upb
        vintage = self.vintage

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if average_security_factor is not UNSET:
            field_dict["averageSecurityFactor"] = average_security_factor
        if average_wac is not UNSET:
            field_dict["averageWac"] = average_wac
        if coupon is not UNSET:
            field_dict["coupon"] = coupon
        if iss_upb is not UNSET:
            field_dict["issUpb"] = iss_upb
        if name is not UNSET:
            field_dict["name"] = name
        if num_loans is not UNSET:
            field_dict["numLoans"] = num_loans
        if num_pools is not UNSET:
            field_dict["numPools"] = num_pools
        if ticker is not UNSET:
            field_dict["ticker"] = ticker
        if type is not UNSET:
            field_dict["type"] = type
        if upb is not UNSET:
            field_dict["upb"] = upb
        if vintage is not UNSET:
            field_dict["vintage"] = vintage

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        average_security_factor = d.pop("averageSecurityFactor", UNSET)

        average_wac = d.pop("averageWac", UNSET)

        coupon = d.pop("coupon", UNSET)

        iss_upb = d.pop("issUpb", UNSET)

        name = d.pop("name", UNSET)

        num_loans = d.pop("numLoans", UNSET)

        num_pools = d.pop("numPools", UNSET)

        ticker = d.pop("ticker", UNSET)

        type = d.pop("type", UNSET)

        upb = d.pop("upb", UNSET)

        vintage = d.pop("vintage", UNSET)

        cohort_summary = cls(
            average_security_factor=average_security_factor,
            average_wac=average_wac,
            coupon=coupon,
            iss_upb=iss_upb,
            name=name,
            num_loans=num_loans,
            num_pools=num_pools,
            ticker=ticker,
            type=type,
            upb=upb,
            vintage=vintage,
        )

        cohort_summary.additional_properties = d
        return cohort_summary

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
